@@ -1,15 +1,19 @@
 package Log::ger::Plugin::MultilevelLog;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-03-07'; # DATE
+our $DATE = '2020-03-09'; # DATE
 our $DIST = 'Log-ger'; # DIST
-our $VERSION = '0.033'; # VERSION
+our $VERSION = '0.034'; # VERSION
 
 use strict;
 use warnings;
 
 use Log::ger::Util;
 
+sub meta { +{
+    v => 1,
+} }
+
 sub get_hooks {
     my %conf = @_;
 
@@ -94,7 +98,7 @@ Log::ger::Plugin::MultilevelLog - Create a log($LEVEL, ...) subroutine/method
 
 =head1 VERSION
 
-version 0.033
+version 0.034
 
 =head1 SYNOPSIS
 
